import Vue from 'vue'
import Vuex from 'vuex'

import { getUser, logout } from '@/api/base'
import { getShopList } from '@/api/shop'
import { getGroupList } from '@/api/goods'
Vue.use(Vuex)

const store = new Vuex.Store({
  state: {
    user: {},
    shopId: window.localStorage.getItem('shopId') || '', // 店铺ID
    shop: {}, // 店铺信息
    groups: [] // 商品分组
  },
  mutations: {
    setUser(state, user) {
      state.user = user
    },
    setShopId(state, shopId) {
      state.shopId = shopId
      window.localStorage.setItem('shopId', shopId)
    },
    setShop(state, data) {
      state.shop = data
    },
    setGroups(state, list) {
      state.groups = list
    }
  },
  actions: {
    // 获取用户信息
    getUser({ commit }) {
      getUser().then(response => {
        commit('setUser', response)
      })
    },
    // 获取店铺信息
    getShop({ commit, state }) {
      getShopList({ shop_id: state.shopId }).then(response => {
        const [first = {}] = response.data || []
        commit('setShop', first)
      })
    },
    // 获取商品分组列表
    getGroups({ commit, state }) {
      getGroupList({ shop_id: state.shopId }).then(response => {
        console.log(response)
        const { data = [] } = response
        commit('setGroups', data)
      })
    },
    // 设置店铺id
    setShopId({ commit }, shopId) {
      commit('setShopId', shopId)
    },
    // 退出登录
    logout({ commit }) {
      return logout().then(response => {
        commit('setUser', {})
        return response
      })
    },
    // 检测登录状态
    async checkLogin({ commit }) {
      const isLogin = await getUser()
        .then(response => {
          commit('setUser', response.data)
          return true
        })
        .catch(() => {
          commit('setUser', {})
          return false
        })
      return isLogin
    }
  }
})

export default store
